#[non_exhaustive]pub struct ListCapacityReservationsInput {
pub next_token: Option<String>,
pub max_results: Option<i32>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.next_token: Option<String>A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated.
max_results: Option<i32>Specifies the maximum number of results to return.
Implementations
Sourceimpl ListCapacityReservationsInput
impl ListCapacityReservationsInput
Sourcepub fn next_token(&self) -> Option<&str>
pub fn next_token(&self) -> Option<&str>
A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated.
Sourcepub fn max_results(&self) -> Option<i32>
pub fn max_results(&self) -> Option<i32>
Specifies the maximum number of results to return.
Sourceimpl ListCapacityReservationsInput
impl ListCapacityReservationsInput
Sourcepub fn builder() -> ListCapacityReservationsInputBuilder
pub fn builder() -> ListCapacityReservationsInputBuilder
Creates a new builder-style object to manufacture ListCapacityReservationsInput.