#[non_exhaustive]pub struct ListCapacityReservationsOutput {
pub next_token: Option<String>,
pub capacity_reservations: Vec<CapacityReservation>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.next_token: Option<String>A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call.
capacity_reservations: Vec<CapacityReservation>The capacity reservations for the current account.
Implementations
Sourceimpl ListCapacityReservationsOutput
impl ListCapacityReservationsOutput
Sourcepub fn next_token(&self) -> Option<&str>
pub fn next_token(&self) -> Option<&str>
A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call.
Sourcepub fn capacity_reservations(&self) -> &[CapacityReservation]
pub fn capacity_reservations(&self) -> &[CapacityReservation]
The capacity reservations for the current account.
Sourceimpl ListCapacityReservationsOutput
impl ListCapacityReservationsOutput
Sourcepub fn builder() -> ListCapacityReservationsOutputBuilder
pub fn builder() -> ListCapacityReservationsOutputBuilder
Creates a new builder-style object to manufacture ListCapacityReservationsOutput.